@@ -64,16 +64,19 @@ def multifunc(function,allvars,procaxis,vardims):
                    ]
     """
     
+
     # add dimensions to variables (i.e. expand array) 
     #in case they are missing (tbi: make this unnecessary)
     dimcount = len(procaxis) 
     for ivar,evar in enumerate(allvars):
-        for idim in reversed(range(dimcount)):
-            if idim not in vardims[ivar]:
+        for idim in reversed(range(len(vardims[ivar]))): #reversed(range(dimcount)):
+            if vardims[ivar][idim] == None: # vardims[ivar]:
                 # if a function has to be applied on that dimension, 
                 #only add an 'axis' for that dimension
                 if procaxis[ivar] == True:
-                    allvars[ivar] = allvars[ivar][newaxes,:]
+                    print 1,ivar,  allvars[ivar].shape
+                    allvars[ivar] = allvars[ivar][newaxis,:]
+                    print ivar,  allvars[ivar].shape
                 # else: length of dimension is 
                 # considered the same for all variables! 
                 # so multiple copies are made from the dimension 
@@ -82,16 +85,27 @@ def multifunc(function,allvars,procaxis,vardims):
                 else:
                     ldone = False
                     for ivar2,evar2 in enumerate(allvars):
-                        if idim in vardims[evar2]:
+                        if idim in vardims[ivar2]:
                             if ldone == False:
-                                allvars[ivar] = repeat(allvars[ivar][newaxis,:],0)
+                                print 2,ivar, allvars[ivar].shape
+                                # dimension length: evar2.shape[vardims[ivar2].index(idim) 
+                                allvars[ivar] = repeat(allvars[ivar][newaxis,:],evar2.shape[vardims[ivar2].index(idim)],0)
+                                print ivar,  allvars[ivar].shape
                             ldone = True
-                vardims[ivar].insert(0,idim)
+                vardims[ivar][idim] = -1
+                for idim2 in range(len(vardims[ivar])): #reversed(range(dimcount)):
+                    if vardims[ivar][idim2] != None:
+                        vardims[ivar][idim2] = vardims[ivar][idim2] + 1
                     
     # put dimensions of all variables arrays in the same order 
     # as the standard order (which is implicitely given by vardims)
+
+    for ivar,evar in enumerate(allvars):
+        print evar.shape, vardims[ivar]
     for ivar,evar in enumerate(allvars):
         allvars[ivar] = transpose(evar,vardims[ivar])
+    for ivar,evar in enumerate(allvars):
+        print evar.shape, vardims[ivar]
     
     # now transpose all matrices in a similar way in such a way that the dimensions 
     # to be processed are at the end
@@ -106,8 +120,15 @@ def multifunc(function,allvars,procaxis,vardims):
     for ivar,evar in enumerate(allvars):
         allvars[ivar] = transpose(evar,trns)
     # ...
+
+    for ivar,evar in enumerate(allvars):
+        print evar.shape, vardims[ivar]
+
     dataouttrns,outcoordstrnstmp = procdf(function,allvars,trnsprocaxis)
 
+    print 'dataouttrns',shape(dataouttrns)
+
+
     #print('shapedataouttrns', shape(dataouttrns), outcoordstrnstmp)
     # 
     # # in case the function introduces extra dimensions: Add these extra dimensions in front of the
